.. DLIS Writer documentation master file, created by
   sphinx-quickstart on Wed Jan  4 17:05:54 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ``dliswriter``'s documentation!
=====================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   aboutdlisformat
   userguide/index.rst
   developerguide/index.rst
   changelog

